# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: metric.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
import connector_pb2 as connector__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cmetric.proto\x12\x10\x63onnector.metric\x1a\x19google/protobuf/any.proto\x1a\x0f\x63onnector.proto\"\xf0\x03\n\x06Metric\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\t\x12\x12\n\nupdated_at\x18\x04 \x01(\t\x12\x0e\n\x06\x63ustom\x18\x05 \x01(\x08\x12;\n\nvalue_type\x18\x06 \x01(\x0e\x32\".connector.metric.Metric.ValueTypeH\x00\x88\x01\x01\x12)\n\x06\x63onfig\x18\x07 \x01(\x0b\x32\x14.google.protobuf.AnyH\x01\x88\x01\x01\x12\x36\n\tconnector\x18\x08 \x01(\x0b\x32\x1e.connector.connector.ConnectorH\x02\x88\x01\x01\x12\x33\n\x11\x63onnected_metrics\x18\t \x03(\x0b\x32\x18.connector.metric.Metric\"\x95\x01\n\tValueType\x12\x16\n\x12VALUE_TYPE_UNKNOWN\x10\x00\x12\x16\n\x12VALUE_TYPE_INTEGER\x10\x01\x12\x14\n\x10VALUE_TYPE_FLOAT\x10\x02\x12\x15\n\x11VALUE_TYPE_STRING\x10\x03\x12\x13\n\x0fVALUE_TYPE_DATE\x10\x04\x12\x16\n\x12VALUE_TYPE_BOOLEAN\x10\x05\x42\r\n\x0b_value_typeB\t\n\x07_configB\x0c\n\n_connector\"L\n\x0eMetricsRequest\x12\x12\n\ncompany_id\x18\x01 \x01(\t\x12\x17\n\nconnection\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\r\n\x0b_connection\"<\n\x0fMetricsResponse\x12)\n\x07metrics\x18\x01 \x03(\x0b\x32\x18.connector.metric.Metric\"0\n\rMetricRequest\x12\x12\n\ncompany_id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"K\n\x0eMetricResponse\x12(\n\x06metric\x18\x01 \x01(\x0b\x32\x18.connector.metric.Metric\x12\x0f\n\x07options\x18\x02 \x03(\t2\xac\x01\n\rMetricService\x12N\n\x07Metrics\x12 .connector.metric.MetricsRequest\x1a!.connector.metric.MetricsResponse\x12K\n\x06Metric\x12\x1f.connector.metric.MetricRequest\x1a .connector.metric.MetricResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'metric_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_METRIC']._serialized_start=79
  _globals['_METRIC']._serialized_end=575
  _globals['_METRIC_VALUETYPE']._serialized_start=386
  _globals['_METRIC_VALUETYPE']._serialized_end=535
  _globals['_METRICSREQUEST']._serialized_start=577
  _globals['_METRICSREQUEST']._serialized_end=653
  _globals['_METRICSRESPONSE']._serialized_start=655
  _globals['_METRICSRESPONSE']._serialized_end=715
  _globals['_METRICREQUEST']._serialized_start=717
  _globals['_METRICREQUEST']._serialized_end=765
  _globals['_METRICRESPONSE']._serialized_start=767
  _globals['_METRICRESPONSE']._serialized_end=842
  _globals['_METRICSERVICE']._serialized_start=845
  _globals['_METRICSERVICE']._serialized_end=1017
# @@protoc_insertion_point(module_scope)
