# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import service_pb2 as service__pb2


class ConnectorServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Services = channel.unary_unary(
                '/connector.service.ConnectorService/Services',
                request_serializer=service__pb2.ServicesRequest.SerializeToString,
                response_deserializer=service__pb2.ServicesResponse.FromString,
                )
        self.Service = channel.unary_unary(
                '/connector.service.ConnectorService/Service',
                request_serializer=service__pb2.ServiceRequest.SerializeToString,
                response_deserializer=service__pb2.ServiceResponse.FromString,
                )


class ConnectorServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Services(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Service(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConnectorServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Services': grpc.unary_unary_rpc_method_handler(
                    servicer.Services,
                    request_deserializer=service__pb2.ServicesRequest.FromString,
                    response_serializer=service__pb2.ServicesResponse.SerializeToString,
            ),
            'Service': grpc.unary_unary_rpc_method_handler(
                    servicer.Service,
                    request_deserializer=service__pb2.ServiceRequest.FromString,
                    response_serializer=service__pb2.ServiceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'connector.service.ConnectorService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ConnectorService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Services(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.service.ConnectorService/Services',
            service__pb2.ServicesRequest.SerializeToString,
            service__pb2.ServicesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Service(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.service.ConnectorService/Service',
            service__pb2.ServiceRequest.SerializeToString,
            service__pb2.ServiceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
